@@ -3,17 +3,20 @@ from time import time
 import numpy as np
 import pyspiel
 from poker_game_runner.state import InfoState, card_num_to_str
+from poker_game_runner.utils import get_hand_type
 from typing import List, Tuple
 from collections import namedtuple
 
 BlindScheduleElement = namedtuple('BlindScheduleElement', 'next_blind_change small_blind big_blind ante')
 Player = namedtuple('Player', 'bot_impl stack id')
 
-def play_tournament_table(bots, start_stack: int, blind_schedule: Tuple[BlindScheduleElement], use_timeout=True):
+def play_tournament_table(bots, start_stack: int, use_timeout=True):
+    
     json_data = []
-    active_players = [Player(bot,start_stack, idx) for idx, bot in enumerate(bots)]
     defeated_players = []
     hand_count = 0
+    active_players = [Player(bot,start_stack, idx) for idx, bot in enumerate(bots)]
+    blind_schedule = get_blind_schedule()
     blinds_iter = iter(blind_schedule)
 
     current_blinds = next(blinds_iter)
@@ -31,7 +34,7 @@ def play_tournament_table(bots, start_stack: int, blind_schedule: Tuple[BlindSch
 
         if hand_count == current_blinds.next_blind_change:
             current_blinds = next(blinds_iter)
-
+            
         newly_defeated_players, active_players = update_active_players(active_players, rewards, current_blinds.big_blind)
 
         defeated_players = defeated_players + newly_defeated_players
@@ -71,11 +74,16 @@ def play_hand(players: List[Player], blinds: List[int], use_timeut = True):
         action = get_player_action(players[current_idx], state, info_state, current_idx, use_timeut)
         apply_player_action(state, info_state, json_events, current_idx, action)
     
-    json_events = json_events + [{"type": "reward", "player": i, "reward": reward} for i, reward in enumerate(state.rewards())]
+    json_events = json_events + [{
+        "type": "reward", 
+        "player": i, 
+        "reward": reward, 
+        "handtype": get_hand_type(list(info_state.board_cards) + list(info_state.player_hands[i])).name
+    } for i, reward in enumerate(state.rewards())]
 
     return list(map(int, state.rewards())), json_events
 
-def get_player_action(player, state, info_state, current_idx, use_timeout):
+def get_player_action(player, state, info_state: InfoState, current_idx: int, use_timeout: bool):
     observation = info_state.to_observation(current_idx, state.legal_actions())
     try:
         action = get_player_action_with_timeout(player, observation, 2 if use_timeout else 1000000)
@@ -83,9 +91,9 @@ def get_player_action(player, state, info_state, current_idx, use_timeout):
         print(f"Bot: '{player.bot_impl.get_name()}' caused an exception!!! Folding on their behalf.")
         print(e)
         action = 0
-    if not action in state.legal_actions():
+    if not (action in observation.legal_actions and action in state.legal_actions()):
         print(f"Bot: '{player.bot_impl.get_name()}' took action '{action}' which is illigal")
-        if 0 in state.legal_actions():
+        if 0 in state.legal_actions() and 0 in observation.legal_actions:
             action = 0
         else:
             action = 1
@@ -156,3 +164,26 @@ def init_game(players, blinds):
     json_events.append({"type": "action", "player": 1, "action": blinds[1]})
     json_events = json_events + [{"type": "deal", "player": int(i/2), "card": card} for i, card in enumerate(map(card_num_to_str, state.history()))]
     return state, info_state, json_events
+
+def get_blind_schedule():
+    return (BlindScheduleElement(10, 10,20,0),     
+                BlindScheduleElement(20, 15,30,0),
+                BlindScheduleElement(30, 20,40,0),
+                BlindScheduleElement(40, 25,50,0),
+                BlindScheduleElement(50, 35,70,0),
+                BlindScheduleElement(60, 45,90,0),
+                BlindScheduleElement(70, 60,120,0),
+                BlindScheduleElement(80, 75,150,0),
+                BlindScheduleElement(90, 100,200,0),
+                BlindScheduleElement(100, 125,250,0),
+                BlindScheduleElement(110, 150,300,0),
+                BlindScheduleElement(120, 200,400,0),
+                BlindScheduleElement(130, 250,500,0),
+                BlindScheduleElement(140, 350,700,0),
+                BlindScheduleElement(150, 450,900,0),
+                BlindScheduleElement(160, 600,1200,0),
+                BlindScheduleElement(170, 750,1500,0),
+                BlindScheduleElement(180, 1000,2000,0),
+                BlindScheduleElement(190, 1250,2500,0),
+                BlindScheduleElement(200, 1500,3000,0),
+                BlindScheduleElement(-1, 2000,4000,0))
\ No newline at end of file
